# Generated by roxygen2: do not edit by hand

export(data_decomposition)
export(data_geomet)
export(data_local)
export(data_mw_variability)
export(data_screening)
export(eda_bbmk_test)
export(eda_kpss_test)
export(eda_mk_test)
export(eda_mks_test)
export(eda_pettitt_test)
export(eda_pp_test)
export(eda_runs_test)
export(eda_sens_trend)
export(eda_spearman_test)
export(eda_white_test)
export(fit_gmle)
export(fit_lmoments)
export(fit_lmoments_kappa)
export(fit_mle)
export(framework_eda)
export(framework_ffa)
export(framework_full)
export(model_assessment)
export(plot_ams_data)
export(plot_bbmk_test)
export(plot_lmom_diagram)
export(plot_mks_test)
export(plot_nsffa_assessment)
export(plot_nsffa_estimates)
export(plot_nsffa_fit)
export(plot_pettitt_test)
export(plot_runs_test)
export(plot_sffa_assessment)
export(plot_sffa_estimates)
export(plot_sffa_fit)
export(plot_spearman_test)
export(select_ldistance)
export(select_lkurtosis)
export(select_zstatistic)
export(uncertainty_bootstrap)
export(uncertainty_rfgpl)
export(uncertainty_rfpl)
export(utils_cdf)
export(utils_generalized_likelihood)
export(utils_log_likelihood)
export(utils_quantiles)
export(utils_sample_lmoments)
export(utils_theoretical_lmoments)
import(ggplot2)
import(patchwork)
importFrom(glue,glue)
importFrom(grDevices,pdf)
importFrom(grid,gpar)
importFrom(grid,grobTree)
importFrom(grid,rectGrob)
importFrom(grid,textGrob)
importFrom(jsonlite,write_json)
importFrom(stats,approx)
importFrom(stats,coef)
importFrom(stats,cor.test)
importFrom(stats,dnorm)
importFrom(stats,embed)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,nlminb)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,pgamma)
importFrom(stats,plnorm)
importFrom(stats,pnorm)
importFrom(stats,qchisq)
importFrom(stats,qgamma)
importFrom(stats,qlnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(utils,read.csv)
