## Model Assessment (`r params$start`-`r params$end`)

<!-- Model Assessment Table -->
```{r, echo = FALSE}

values <- c(
	params$metrics$R2,
	params$metrics$RMSE,
	params$metrics$bias,
	params$metrics$AIC_RMSE,
	params$metrics$BIC_RMSE,
	params$metrics$AIC_MLL,
	params$metrics$BIC_MLL
)

statistics <- c(
	"Model Validation: Coefficient of Determination",
	"Model Validation: RMSE",
	"Model Validation: Bias",
	"Akaike Information Criterion (RMSE)",
	"Bayesian Information Criterion (RMSE)",
	"Akaike Information Criterion (MLL)",
	"Bayesian Information Criterion (MLL)"
)

# S-FFA Only
if ("AW" %in% params$metrics) {

	values <- c(
		values,
		params$metrics$AW,
		params$metrics$POC,
		params$metrics$CWI
	)

	statistics <- c(
		statistics,
		"Confidence Intervals: Average Width",
		"Confidence Intervals: Percentage of Coverage",
		"Confidence Intervals: Confidence Width Indicator"
	)
}

assessment_df <- data.frame(
	Statistic = statistics,
	Value = values
)

knitr::kable(
	assessment_df, 
	format = "markdown",
	align = "lr"
)
```

```{r, echo = FALSE, out.width = "80%", fig.align = "center", dpi = 150}
knit_plot(params, glue("assessment_{params$start}_{params$end}.png"))
```
