### Sen's Trend Estimator (Variability) 

For more information, see [here](https://rileywheadon.github.io/ffa-framework/articles/eda-trend-ams-mean.html#sens-trend-estimator). 

Identified Trend: *y = `r round(params$slope, 2)`x + `r round(params$intercept, 3)`*

```{r, echo = FALSE, out.width = "80%", fig.align = "center", dpi = 150}
knit_plot(params, glue("sens_variance_{params$start}_{params$end}.png"))
```


