## '`r params$method`' Parameter Estimation (`r params$start`-`r params$end`)

**Distribution**: `r params$distribution`

**Estimated Parameters**: `r round(params$params, 4)`

```{r, echo = FALSE, out.width = "80%", fig.align = "center", dpi = 150}
knit_plot(params, glue("estimation_{params$start}_{params$end}.png"))
```


