## '`r params$method`' Distribution Selection (`r params$start`-`r params$end`)

**Recommended Distribution**: `r params$recommendation`

<!-- Model Selection Table -->
```{r, echo = FALSE}
if (!is.null(params$metrics)) {

	df <- data.frame(
		Distribution = names(params$metrics),
		Metric = round(unname(unlist(params$metrics)), 4)
	)

	knitr::kable(df, align = "cc")

}
```

<!-- Model Selection Plot -->
```{r, echo = FALSE, out.width = "80%", fig.align = "center", dpi = 150}
knit_plot(params, glue("selection_{params$start}_{params$end}.png"))
```


