### Mann-Kendall Test

For more information, see [here](https://rileywheadon.github.io/ffa-framework/articles/eda-trend-ams-mean.html#mann-kendall-mk-test). 

- *Null Hypothesis*: `r params$null_hypothesis`
- *Alternative Hypothesis*: `r params$alternative_hypothesis`

Results:

```{r, include = FALSE}
p_value <- if (params$p_value < 0.001) "<0.001" else round(params$p_value, 3)

if (params$reject) {
	outcome <- "reject"
	conclusion <- "evidence of a monotonic trend in the mean"
} else {
	outcome <- "fail to reject"	
	conclusion <- "no evidence of a monotonic trend in the mean"
}
```

- The Mann-Kendall test yielded a p-value of `r p_value`.
- At a significance level of `r params$alpha`, we `r outcome` the null hypothesis.
- Therefore, there is `r conclusion`.


